==> checkstyle-8.45.1-tests.jar: com/puppycrawl/tools/checkstyle/checks/javadoc/summaryjavadoc/InputSummaryJavadocInlineForbidden.java <==
/*
SummaryJavadocCheckTest
violateExecutionOnNonTightHtml = (default)false
forbiddenSummaryFragments = @return the *|This method returns
period = (default).


*/

package com.puppycrawl.tools.checkstyle.checks.javadoc.summaryjavadoc;

public class InputSummaryJavadocInlineForbidden {

    /**
     * {@summary A simple correct Javadoc.}
     */
    void foo1() { // ok
    }

    /**
     * {@summary This code {@input Javadoc} is right.}
     */
    void foo3() { // ok
    }

    /**
     * {@summary This code is wrong }
     */
    void foo5() { // violation
    }

    /**
     * {@summary This code {@see Javadoc} is wrong } // violation
     */
    void foo6() { // violation
    }

    /**
     * {@summary As of , replaced by {@link #setBounds(int, int, int, int)}}
     */
    void foo11() { // violation
    }

    /**
     * {@summary This method returns something.}
     */
    public static final byte NUL = 0; // violation

    /**
     * {@summary <a href="mailto:vlad@htmlbook.ru"/>}
     */
    class InnerInputCorrectJavaDocParagraphCheck { // violation

        /**
         * {@summary foooo@foooo}
         */
        public static final byte NUL = 0; // violation

        /**
         * {@summary Some java@doc.}
         */
        public static final byte NUL_2 = 0; // ok

        /**
         * {@summary @return the
         * customer ID some javadoc.}
         */
        int geId() { // violation
            return 666;
        }

        /**
         * {@summary As of JDK 1.1, replaced by {@link #setBounds(int, int, int, int)}.}
         */
        void foo3() {
        } // ok

    }

    /**
     * {@summary A {@code InnerInputCorrectJavaDocParagraphCheck} is a simple code.}
     */
    InputSummaryJavadocInlineForbidden.InnerInputCorrectJavaDocParagraphCheck anon =
            new InputSummaryJavadocInlineForbidden.InnerInputCorrectJavaDocParagraphCheck() {

                /**
                 * mm{@inheritDoc}
                 */
                void foo7() { // violation
                }

                /**
                 * {@summary {@code see}.}
                 */
                void foo10() { // ok
                }
            };

    /**
     * {@summary first sentence is normally the summary.
     * Use of html tags:
     * {@throws error}
     * <ul>
     * <li>Item one.</li>
     * <li>Item two.</li>
     * </ul>
     * <p> This is the paragraph.</p>
     * <h1> This is a heading </h1>}
     */
    public void validInlineJavadoc() // violation
    {
    }

    /**
     * {@summary <p> </p>}
     */
    void foo12() { // violation
    }

    /**
     * Sentence starts as a plain text sentence
     * {@summary ... but ends in the summary tag}
     */
    public class TestClass {} // violation

    /**
     * {@summary first sentence is normally the summary.}
     *
     * @param a some parameter.
     * @return This method returns a, this statement is allowed in return.
     */
    public int validInlineJavadocReturn(int a) // ok
    {
        return a;
    }
}

==> checkstyle-9.3-tests.jar: com/puppycrawl/tools/checkstyle/checks/javadoc/summaryjavadoc/InputSummaryJavadocInlineForbidden.java <==
/*
SummaryJavadoc
violateExecutionOnNonTightHtml = (default)false
forbiddenSummaryFragments = @return the *|This method returns
period = (default).


*/

package com.puppycrawl.tools.checkstyle.checks.javadoc.summaryjavadoc;

public class InputSummaryJavadocInlineForbidden {

    /**
     * {@summary A simple correct Javadoc.}
     */
    void foo1() { // ok
    }

    /**
     * {@summary This code {@input Javadoc} is right.}
     */
    void foo3() { // ok
    }
    // violation below
    /**
     * {@summary This code is wrong }
     */
    void foo5() {
    }
    // violation below
    /**
     * {@summary This code {@see Javadoc} is wrong }
     */
    void foo6() {
    }
    // violation below
    /**
     * {@summary As of , replaced by {@link #setBounds(int, int, int, int)}}
     */
    void foo11() {
    }
    // violation below
    /**
     * {@summary This method returns something.}
     */
    public static final byte NUL = 0;
    // violation below
    /**
     * {@summary <a href="mailto:vlad@htmlbook.ru"/>}
     */
    class InnerInputCorrectJavaDocParagraphCheck {
    // violation below
        /**
         * {@summary foooo@foooo}
         */
        public static final byte NUL = 0;

        /**
         * {@summary Some java@doc.}
         */
        public static final byte NUL_2 = 0; // ok
    // violation below
        /**
         * {@summary @return the
         * customer ID some javadoc.}
         */
        int geId() {
            return 666;
        }

        /**
         * {@summary As of JDK 1.1, replaced by {@link #setBounds(int, int, int, int)}.}
         */
        void foo3() {
        } // ok

    }

    /**
     * {@summary A {@code InnerInputCorrectJavaDocParagraphCheck} is a simple code.}
     */
    InputSummaryJavadocInlineForbidden.InnerInputCorrectJavaDocParagraphCheck anon =
            new InputSummaryJavadocInlineForbidden.InnerInputCorrectJavaDocParagraphCheck() {
                // violation below
                /**
                 * mm{@inheritDoc}
                 */
                void foo7() {
                }

                /**
                 * {@summary {@code see}.}
                 */
                void foo10() { // ok
                }
            };
    // violation below
    /**
     * {@summary first sentence is normally the summary.
     * Use of html tags:
     * {@throws error}
     * <ul>
     * <li>Item one.</li>
     * <li>Item two.</li>
     * </ul>
     * <p> This is the paragraph.</p>
     * <h1> This is a heading </h1>}
     */
    public void validInlineJavadoc()
    {
    }
    // violation below
    /**
     * {@summary <p> </p>}
     */
    void foo12() {
    }
    // violation below
    /**
     * Sentence starts as a plain text sentence
     * {@summary ... but ends in the summary tag}
     */
    public class TestClass {}

    /**
     * {@summary first sentence is normally the summary.}
     *
     * @param a some parameter.
     * @return This method returns a, this statement is allowed in return.
     */
    public int validInlineJavadocReturn(int a) // ok
    {
        return a;
    }
}
